@@ -8,7 +8,7 @@ Title: tn93.py
 Description: Implementation of Tamura-Nei distance calculation for pair of HIV sequences
 Usage: Used by other software
 Date Created: 2022-08-09 18:11
-Last Modified: Thu 06 Oct 2022 02:29:25 PM EDT
+Last Modified: Thu 20 Oct 2022 12:49:01 PM EDT
 Author: Reagan Kelly (ylb9@cdc.gov)
 """
 
@@ -24,11 +24,11 @@ import sys
 from itertools import chain
 from Bio import SeqIO
 import numpy as np
-import argparser
+import argparse
 
 
 def main(args):
-    parser = argparser.setup_parser()
+    parser = setup_parser()
     args = parser.parse_args(args)
     tn93 = TN93(
         verbose=args.verbose,
@@ -71,6 +71,67 @@ def main(args):
             writer.writerows(final_distance)
 
 
+def setup_parser():
+    parser = argparse.ArgumentParser()
+    parser.add_argument(
+        "-i",
+        "--input_file",
+        action="store",
+        required=True,
+        help="Path to the input fasta file",
+    )
+    parser.add_argument(
+        "-m",
+        "--match_mode",
+        action="store",
+        required=True,
+        help="""
+        How to handle ambiguities. This can be one of four options:
+        average - Averages the possible nucleotide values for each ambiguity in a sequence;
+        resolve - Tries to resolve ambiguities;
+        skip - Ignores gaps and ambiguities;
+        gapmm - Treats gaps in only one sequence as 'N's;
+        """,
+    )
+    parser.add_argument(
+        "-o",
+        "--output",
+        action="store",
+        required=True,
+        help="The name of the output file to create",
+    )
+    parser.add_argument(
+        "-g",
+        "--max_ambig_fraction",
+        action="store",
+        required=False,
+        default=1.0,
+        help="Sequences that have proportions of ambiguities lower than this value will be resolved, otherwise they will be averaged (RESOLVE only) (Default: 1.0)",
+    )
+    parser.add_argument(
+        "-v",
+        "--verbose",
+        action="count",
+        default=0,
+        help="Verbosity, One copy prints intermediate values and final counts, two copies produces a CSV file with pairwise counts for each non-gap nucleotide",
+    )
+    parser.add_argument(
+        "-n",
+        "--ignore_terminal_gaps",
+        action="store_true",
+        default=False,
+        help="Should gaps at the beginning and end of a sequence be ignored (GAPMM only)? (Default: False)",
+    )
+    parser.add_argument(
+        "-j",
+        "--json_output",
+        action="store_true",
+        default=False,
+        help="Should the output be in JSON format? (Default: False)",
+    )
+    return parser
+
+
 class TN93(object):
     def __init__(
         self,
